==> pykoa-1.4.5.tar.gz: pykoa-1.4.5/README.md <==
KOA Table Access Protocol (TAP) Client
======================================

Version 1 of PyKOA offers access to public raw science and calibration files 
acquired with the HIRES echelle-spectrograph, and for Keck Observatory PIs, 
secure access to their protected data with the KOA credentials already assigned
to them. The remaining Keck instruments are expected to be available before the
end of 2020. Queries made through PyKOA are underpinned by nexsciTAP, a NExScI 
Python-based server that implements the IVOA Table Access Protocol (TAP). 
This design enables a rich variety of searches, including cone, box, polygon, 
or all-sky spatial searches; temporal searches; searches on program 
infortmation; and complex searches on multiple attributes.

The Keck Observatory Archive (KOA) is a collaboration between the NASA 
Exoplanet Science Institute (NExScI) and the W. M. Keck Observatory (WMKO). 
NExScI is sponsored by NASA's Exoplanet Exploration Program, and operated by 
the California Institute of Technology in coordination with the Jet Propulsion 
Laboratory (JPL).

If you used PyKOA in your resesearch, please acknowledge KOA as follows: 

    "This research has made use of the Keck Observatory Archive (KOA), which 
    is operated by the W. M. Keck Observatory and the NASA Exoplanet Science 
    Institute (NExScI), under contract with the National Aeronautics and 
    Space Administration." 

Please also acknowledge the PI(s) of datasets that have been accesses 
through PyKOA.

==> pykoa-1.5.2.tar.gz: pykoa-1.5.2/README.md <==
KOA Table Access Protocol (TAP) Client
======================================

Version 1 of PyKOA offers access to public raw science and calibration files 
acquired with the HIRES echelle-spectrograph, and for Keck Observatory PIs, 
secure access to their protected data with the KOA credentials already assigned
to them. The remaining Keck instruments are expected to be available before the
end of 2020. Queries made through PyKOA are underpinned by nexsciTAP, a NExScI 
Python-based server that implements the IVOA Table Access Protocol (TAP). 
This design enables a rich variety of searches, including cone, box, polygon, 
or all-sky spatial searches; temporal searches; searches on program 
infortmation; and complex searches on multiple attributes.

The Keck Observatory Archive (KOA) is a collaboration between the NASA 
Exoplanet Science Institute (NExScI) and the W. M. Keck Observatory (WMKO). 
NExScI is sponsored by NASA's Exoplanet Exploration Program, and operated by 
the California Institute of Technology in coordination with the Jet Propulsion 
Laboratory (JPL).

If you used PyKOA in your research, please acknowledge KOA as follows: 

    "This research has made use of the Keck Observatory Archive (KOA), which 
    is operated by the W. M. Keck Observatory and the NASA Exoplanet Science 
    Institute (NExScI), under contract with the National Aeronautics and 
    Space Administration." 

Please also acknowledge the PI(s) of datasets that have been accesses 
through PyKOA.
